/**
 * Vrátí kořenovou URL serveru na základě aktuálního prostředí (vývojovou či produkční).
 * 
 * @returns kořenová URL serveru
 */
export const getBaseUrl = (): string => {
    if (process.env.PUBLIC_URL) {
        return process.env.PUBLIC_URL;
    }
    return 'http://localhost:3001';
}

const LOGIN_KEY = "login";

/**
 * Uloží login do local storage prohlížeče.
 * 
 * @param login login
 */
export const storeLogin = (login: string) => {
    localStorage.setItem(LOGIN_KEY, login);
}

/**
 * Vrátí login z local storage, pokud tam je.
 * 
 * @returns login nebo null
 */
export const getLogin = (): string | null => {
    return localStorage.getItem(LOGIN_KEY);
}

/**
 * Odstraní login z local storage, pokud tam je.
 */
export const deleteLogin = () => {
    localStorage.removeItem(LOGIN_KEY);
}